from machine import Pin, I2C
from time import sleep
from bme680 import *
import picoexplorer as display
import rv3028_rtc
import utime

sda=machine.Pin(20)
scl=machine.Pin(21)
i2c=machine.I2C(0,sda=sda, scl=scl, freq=400000)
rtc=rv3028_rtc.RV3028(0x52, i2c, "LSM")

bme = BME680_I2C(i2c=i2c)

# Initialise display with a bytearray display buffer
buf = bytearray(display.get_width() * display.get_height() * 2)
display.init(buf)

# sets up a handy function we can call to clear the screen
def clear():
    display.set_pen(0, 0, 0)
    display.clear()
    display.update()

while True:
  try:
    temp = str(round(bme.temperature, 2)) + ' C'
    
    hum = str(round(bme.humidity, 2)) + ' %'
    
    pres = str(round(bme.pressure, 2)) + ' hPa'
    
    gas = str(round(bme.gas/1000, 2)) + ' KOhms'
    
# Affichage de l'heure
    
    heure = rtc.get_hours()
    minute = rtc.get_minutes()
    seconde = rtc.get_seconds()
    
    joursemaine = rtc.get_weekday(day_type="long")
    nommois = rtc.get_month(month_type="short")
    datedujour = rtc.get_date(date_type="ordinal")
    an = rtc.get_year()
    
    heure = "      {:0>2}:{:0>2}:{:0>2}" .format (str(heure), str(minute), str(seconde))
    date = '%s %s %s %s' % (joursemaine, datedujour, nommois, an)

    print (heure)
    print(joursemaine, datedujour, nommois, an)
    print('Température :', temp)
    print('Humidité :', hum)
    print('Pression :', pres)
    print('Gaz :', gas)
    print('-------')
   
    display.set_pen(255, 255, 255)                    # change the pen colour
    display.text(heure, 10, 5, 240, 2)  # display some text on the screen
    
    display.set_pen(255, 255, 255)                    # change the pen colour
    display.text(date, 10, 20, 240, 2)  # display some text on the screen
    

    display.set_pen(255, 255, 255)                    # change the pen colour
    display.text("Temperature :", 10, 40, 240, 3)  # display some text on the screen
    display.set_pen(255, 255, 255)                    # change the pen colour
    display.text(temp, 10, 60, 240, 3)  # display some text on the screen

    display.set_pen(255, 0, 0)                    # change the pen colour
    display.text("Humidite :", 10, 90, 240, 3)  # display some text on the screen
    display.set_pen(255, 0, 0)                    # change the pen colour
    display.text(hum, 10, 110, 240, 3)  # display some text on the screen

    display.set_pen(0, 0, 255)                    # change the pen colour
    display.text("Pression :", 10, 150, 240, 3)  # display some text on the screen
    display.set_pen(0, 0, 255)                    # change the pen colour
    display.text(pres, 10, 170, 240, 3)  # display some text on the screen

    display.set_pen(0, 255, 0)                    # change the pen colour
    display.text("Gaz :", 10, 200, 240, 3)  # display some text on the screen
    display.set_pen(0, 255, 0)                    # change the pen colour
    display.text(gas, 10, 220, 240, 3)  # display some text on the screen
    display.update()                                  # update the display

    

  except OSError as e:
    print('Erreur de lecture.')
   
  sleep(5)
  clear()
